@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/ed.h,v 3.29 2000/07/04 19:37:35 christos Exp $ */
+/* $Header: /src/pub/tcsh/ed.h,v 3.31 2001/02/19 23:30:44 kim Exp $ */
 /*
  * ed.h: Editor declarations and globals
  */
@@ -44,9 +44,9 @@
 #define TABSIZE		8	/* usually 8 spaces/tab */
 #define MAXMACROLEVELS	10	/* max number of nested kbd macros */
 
-#ifndef WINNT
+#ifndef WINNT_NATIVE
 # define NT_NUM_KEYS	256
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
 
 /****************************************************************************/
 /* stuff for the different states returned by the character editor routines */
@@ -132,8 +132,11 @@ EXTERN Char *Mark;		/* the emacs "mark" (dot is Cursor) */
 EXTERN Char DoingArg;		/* true if we have an argument */
 EXTERN int Argument;		/* "universal" argument value */
 EXTERN KEYCMD LastCmd;		/* previous command executed */
-EXTERN Char KillBuf[INBUFSIZE];	/* kill buffer */
-EXTERN Char *LastKill;		/* points to end of kill buffer */
+EXTERN CStr *KillRing;		/* kill ring */
+EXTERN int KillRingMax;		/* max length of kill ring */
+EXTERN int KillRingLen;		/* current length of kill ring */
+EXTERN int KillPos;		/* points to next kill */
+EXTERN int YankPos;		/* points to next yank */
 
 EXTERN Char UndoBuf[INBUFSIZE];
 EXTERN Char *UndoPtr;
@@ -188,9 +191,9 @@ EXTERN Char T_HasMeta;		/* true if we have a meta key */
  * Terminal dependend data structures
  */
 typedef struct {
-#ifdef WINNT
+#ifdef WINNT_NATIVE
     int dummy;
-#else /* !WINNT */
+#else /* !WINNT_NATIVE */
 # if defined(POSIX) || defined(TERMIO)
 #  ifdef POSIX
     struct termios d_t;
@@ -214,7 +217,7 @@ typedef struct {
 # ifdef TIOCGLTC
     struct ltchars d_ltc;
 # endif /* TIOCGLTC */
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
 } ttydata_t;
 
 #define MODE_INSERT	0
