@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/ed.xmap.c,v 3.22 2000/06/11 02:14:13 kim Exp $ */
+/* $Header: /src/pub/tcsh/ed.xmap.c,v 3.24 2001/04/27 22:37:03 christos Exp $ */
 /*
  * ed.xmap.c: This module contains the procedures for maintaining
  *	      the extended-key map.
@@ -92,7 +92,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: ed.xmap.c,v 3.22 2000/06/11 02:14:13 kim Exp $")
+RCSID("$Id: ed.xmap.c,v 3.24 2001/04/27 22:37:03 christos Exp $")
 
 #include "ed.h"
 #include "ed.defns.h"
@@ -719,6 +719,9 @@ parseescape(ptr)
 	case 'v':
 	    c = CTL_ESC('\013');         /* Vertical Tab */
 	    break;
+	case '\\':
+	    c = '\\';
+	    break;
 	case '0':
 	case '1':
 	case '2':
@@ -788,11 +791,11 @@ unparsestring(str, buf, sep)
 
     b = buf;
     if (sep[0])
-#ifndef WINNT
+#ifndef WINNT_NATIVE
 	*b++ = sep[0];
-#else /* WINNT */
+#else /* WINNT_NATIVE */
 	*b++ = CHAR & sep[0];
-#endif /* !WINNT */
+#endif /* !WINNT_NATIVE */
 
     for (l = 0; l < str->len; l++) {
 	p = str->buf[l];
@@ -834,11 +837,11 @@ unparsestring(str, buf, sep)
 	}
     }
     if (sep[0] && sep[1])
-#ifndef WINNT
+#ifndef WINNT_NATIVE
 	*b++ = sep[1];
-#else /* WINNT */
+#else /* WINNT_NATIVE */
 	*b++ = CHAR & sep[1];
-#endif /* !WINNT */
+#endif /* !WINNT_NATIVE */
     *b++ = 0;
     return buf;			/* should check for overflow */
 }
