@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/tw.parse.c,v 3.88 2000/06/11 02:14:17 kim Exp $ */
+/* $Header: /src/pub/tcsh/tw.parse.c,v 3.90 2001/03/18 19:06:32 christos Exp $ */
 /*
  * tw.parse.c: Everyone has taken a shot in this futile effort to
  *	       lexically analyze a csh line... Well we cannot good
@@ -39,15 +39,15 @@
  */
 #include "sh.h"
 
-RCSID("$Id: tw.parse.c,v 3.88 2000/06/11 02:14:17 kim Exp $")
+RCSID("$Id: tw.parse.c,v 3.90 2001/03/18 19:06:32 christos Exp $")
 
 #include "tw.h"
 #include "ed.h"
 #include "tc.h"
 
-#ifdef WINNT
+#ifdef WINNT_NATIVE
 #include "nt.const.h"
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
 #define EVEN(x) (((x) & 1) != 1)
 
 #define DOT_NONE	0	/* Don't display dot files		*/
@@ -824,21 +824,21 @@ recognize(exp_name, item, name_length, numitems, enhanced)
     Char MCH1, MCH2;
     register Char *x, *ent;
     register int len = 0;
-#ifdef WINNT
+#ifdef WINNT_NATIVE
     struct varent *vp;
     int igncase;
     igncase = (vp = adrof(STRcomplete)) != NULL &&
 	Strcmp(*(vp->vec), STRigncase) == 0;
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
 
     if (numitems == 1) {	/* 1st match */
 	copyn(exp_name, item, MAXNAMLEN);
 	return (0);
     }
     if (!enhanced
-#ifdef WINNT
+#ifdef WINNT_NATIVE
 	&& !igncase
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
     ) {
 	for (x = exp_name, ent = item; *x && (*x & TRIM) == (*ent & TRIM); x++, ent++)
 	    len++;
@@ -992,10 +992,10 @@ tw_collect_items(command, looking, exp_dir, exp_name, target, pat, flags)
 	case RECOGNIZE_ALL:
 	case RECOGNIZE_SCROLL:
 
-#ifdef WINNT
+#ifdef WINNT_NATIVE
  	    igncase = (vp = adrof(STRcomplete)) != NULL && 
 		Strcmp(*(vp->vec), STRigncase) == 0;
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
 	    enhanced = (vp = adrof(STRcomplete)) != NULL && !Strcmp(*(vp->vec),STRenhance);
 	    if (enhanced || igncase) {
 	        if (!is_prefixmatch(target, item, igncase)) 
@@ -1318,6 +1318,9 @@ tw_list_items(looking, numitems, list_max)
     int max_items = 0;
     int max_rows = 0;
 
+    if (numitems == 0)
+	return;
+
     if ((ptr = varval(STRlistmax)) != STRNULL) {
 	while (*ptr) {
 	    if (!Isdigit(*ptr)) {
@@ -1594,7 +1597,12 @@ t_search(word, wp, command, max_word_length, looking, list_max, pat, suf)
     case TW_PATH | TW_DIRECTORY:
     case TW_PATH | TW_COMMAND:
 	if ((dir_fd = opendir(short2str(exp_dir))) == NULL) {
-	    xprintf("%S: %s\n", exp_dir, strerror(errno));
+ 	    if (command == RECOGNIZE)
+ 		xprintf("\n");
+ 	    xprintf("%S: %s", exp_dir, strerror(errno));
+ 	    if (command != RECOGNIZE)
+ 		xprintf("\n");
+ 	    NeedsRedraw = 1;
 	    return -1;
 	}
 	if (exp_dir[Strlen(exp_dir) - 1] != '/')
@@ -1718,10 +1726,10 @@ extract_dir_and_name(path, dir, name)
     register Char *p;
 
     p = Strrchr(path, '/');
-#ifdef WINNT
+#ifdef WINNT_NATIVE
     if (p == NULL)
 	p = Strrchr(path, ':');
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
     if (p == NULL) {
 	copyn(name, path, MAXNAMLEN);
 	dir[0] = '\0';
@@ -1779,6 +1787,13 @@ tilde(new, old)
 	    new[0] = '\0';
 	    return NULL;
 	}
+#ifdef apollo
+	/* Special case: if the home directory expands to "/", we do
+	 * not want to create "//" by appending a slash from o.
+	 */
+	if (new[0] == '/' && new[1] == '\0' && *o == '/')
+	    ++o;
+#endif /* apollo */
 	(void) Strcat(new, o);
 	return new;
 
